@@ -5,7 +5,7 @@ import time
 URL = 'url'
 METHOD = 'method'
 HEADERS = 'headers'
-PAYLOAD = 'payload'
+DATA = 'data'
 STATUS_CODE = 'status_code'
 CONTENT = 'content'
 
@@ -26,6 +26,16 @@ def is_unauthorized(status_code):
   return str(status_code) in ['401', '403']
 
 
+def is_json(value):
+  if not value:
+    return False
+  try:
+    json.loads(value)
+  except ValueError:
+    return False
+  return True
+
+
 def request(method, url, **kwargs):
   result = getattr(requests, method.lower())(url, **kwargs)
   wait = 1
@@ -34,13 +44,13 @@ def request(method, url, **kwargs):
     wait = wait * 2 if wait < 10 else 10
     result = getattr(requests, method.lower())(url, **kwargs)
   content = None
-  if result.text and len(result.text) > 0:
+  if result.text and is_json(result.text):
     content = json.loads(result.text)
   return {
       URL: url,
       HEADERS: kwargs.get(HEADERS),
       METHOD: method,
-      PAYLOAD: kwargs.get(PAYLOAD),
+      DATA: kwargs.get(DATA),
       STATUS_CODE: result.status_code,
       CONTENT: content
   }
